sqlobject.versioning package — SQLObject 3.9.1 documentation

# sqlobject.versioning package

class `sqlobject.versioning.` `Version`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `getChangedFields`()
  `j` = version
  `nextVersion`()
  `q` = version
  `restore`()
  classmethod `select`(clause=None, *args, **kw)
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.versioning.Version`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'version'

class `sqlobject.versioning.` `Versioning`(extraCols=None)

  Bases: `object`

  `createTable`(soClass, connection, extra_sql, post_funcs)
  `createVersionTable`(cls, conn)
  `rowUpdate`(instance, kwargs)

`sqlobject.versioning.` `getColumns`(columns, cls)

## Subpackages

- sqlobject.versioning.test package
  - Submodules
    - sqlobject.versioning.test.test_version module